import request from '@/router/axios'

export function getList(query) {
  return request({
    url: '/job/sys-job-log/page',
    method: 'get',
    params: query
  })
}
// 同一用户，连续2个月结算金额相同
export function memberSettleSameAmount(query, uuid) {
  return request({
    url: `admin/risk-control/member/settle-same-amount/${uuid}`,
    method: 'get',
    params: query
  })
}
export function exportMember(uuid) {
  return request({
    url: `admin/risk-control/member/settle-same-amount/export/${uuid}`,
    method: 'get',
    responseType: 'arraybuffer'
  })
}
// 同一企业，给2个及以上用户支付相同金额
export function enterpriseSettleSameAmount(query, uuid) {
  return request({
    url: `admin/risk-control/enterprise/settle-same-amount/${uuid}`,
    method: 'get',
    params: query
  })
}
export function exportEnterpri(uuid) {
  return request({
    url: `admin/risk-control/enterprise/settle-same-amount/export/${uuid}`,
    method: 'get',
    responseType: 'arraybuffer'
  })
}
// 同一用户，连续多月没有指定任务类型
export function memberTaskType(query, uuid) {
  return request({
    url: `admin/risk-control/member/task-type/${uuid}`,
    method: 'get',
    params: query
  })
}
export function exportTaskType(uuid) {
  return request({
    url: `admin/risk-control/member/task-type/export/${uuid}`,
    method: 'get',
    responseType: 'arraybuffer'
  })
}
// 同一用户，连续3个月结算金额超过14万
export function settleSameAmountOverrun(query, uuid) {
  return request({
    url: `admin/risk-control/member/settle-amount/overrun/${uuid}`,
    method: 'get',
    params: query
  })
}
export function exportOverrun(uuid) {
  return request({
    url: `admin/risk-control/member/settle-amount/overrun/export/${uuid}`,
    method: 'get',
    responseType: 'arraybuffer'
  })
}
